From: "Paul E. McKenney" <paul...@linux.vnet.ibm.com>

This commit makes the torture scripts a bit more RCU-independent.

Signed-off-by: Paul E. McKenney <paul...@linux.vnet.ibm.com>
---
 tools/testing/selftests/rcutorture/bin/functions.sh | 8 ++++----
 tools/testing/selftests/rcutorture/bin/kvm.sh       | 4 ++--
 2 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/tools/testing/selftests/rcutorture/bin/kvm.sh 
b/tools/testing/selftests/rcutorture/bin/kvm.sh
index d397ecc55293..ea59e2950f14 100644
--- a/tools/testing/selftests/rcutorture/bin/kvm.sh
+++ b/tools/testing/selftests/rcutorture/bin/kvm.sh
@@ -141,7 +141,7 @@ do
                ;;
        --qemu-cmd)
                checkarg --qemu-cmd "(qemu-system-...)" $# "$2" 'qemu-system-' 
'^--'
-               RCU_QEMU_CMD="$2"; export RCU_QEMU_CMD
+               TORTURE_QEMU_CMD="$2"; export TORTURE_QEMU_CMD
                shift
                ;;
        --results)
@@ -377,7 +377,7 @@ then
        echo TORTURE_BUILDONLY="$TORTURE_BUILDONLY; export TORTURE_BUILDONLY"
        echo TORTURE_INITRD="$TORTURE_INITRD; export TORTURE_INITRD"
        echo TORTURE_KMAKE_ARG="$TORTURE_KMAKE_ARG; export TORTURE_KMAKE_ARG"
-       echo RCU_QEMU_CMD="$RCU_QEMU_CMD; export RCU_QEMU_CMD"
+       echo TORTURE_QEMU_CMD="$TORTURE_QEMU_CMD; export TORTURE_QEMU_CMD"
        echo TORTURE_QEMU_INTERACTIVE="$TORTURE_QEMU_INTERACTIVE;
                export TORTURE_QEMU_INTERACTIVE"
        echo TORTURE_QEMU_MAC="$TORTURE_QEMU_MAC; export TORTURE_QEMU_MAC"
diff --git a/tools/testing/selftests/rcutorture/bin/functions.sh 
b/tools/testing/selftests/rcutorture/bin/functions.sh
index 41fb52b805e4..6b2adb29b073 100644
--- a/tools/testing/selftests/rcutorture/bin/functions.sh
+++ b/tools/testing/selftests/rcutorture/bin/functions.sh
@@ -79,12 +79,12 @@ configfrag_hotplug_cpu () {
 # identify_qemu builddir
 #
 # Returns our best guess as to which qemu command is appropriate for
 # the kernel at hand.  Override with the RCU_QEMU_CMD environment variable.
 identify_qemu () {
        local u="`file "$1"`"
-       if test -n "$RCU_QEMU_CMD"
+       if test -n "$TORTURE_QEMU_CMD"
        then
-               echo $RCU_QEMU_CMD
+               echo $TORTURE_QEMU_CMD
        elif echo $u | grep -q x86-64
        then
                echo qemu-system-x86_64
@@ -98,7 +98,7 @@ identify_qemu () {
                echo Cannot figure out what qemu command to use! 1>&2
                echo file $1 output: $u
                # Usually this will be one of /usr/bin/qemu-system-*
                # Use RCU_QEMU_CMD environment variable or appropriate
                # argument to top-level script.
                exit 1
        fi
@@ -79,12 +79,12 @@ configfrag_hotplug_cpu () {
 #
 # Returns our best guess as to which qemu command is appropriate for
-# the kernel at hand.  Override with the RCU_QEMU_CMD environment variable.
+# the kernel at hand.  Override with the TORTURE_QEMU_CMD environment variable.
 identify_qemu () {
        local u="`file "$1"`"
@@ -98,7 +98,7 @@ identify_qemu () {
                echo file $1 output: $u
                # Usually this will be one of /usr/bin/qemu-system-*
-               # Use RCU_QEMU_CMD environment variable or appropriate
+               # Use TORTURE_QEMU_CMD environment variable or appropriate
                # argument to top-level script.
                exit 1
-- 
1.8.1.5

--
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/

Reply via email to